pub struct CoordinatorInfo { /* private fields */ }Expand description
CoordinatorInfo describes an active coordinator. It provides the coordinator type and the sender for the coordinator. A coordinator, is a specialization of a component, and shares the same instruction set as all other components and coordinators.
Implementations
Sourceimpl CoordinatorInfo
impl CoordinatorInfo
Sourcepub const fn new(
coordinator: String,
sender: Sender<ComponentCmd>,
) -> CoordinatorInfo
pub const fn new( coordinator: String, sender: Sender<ComponentCmd>, ) -> CoordinatorInfo
Creates and new CoordinatorInfo struct and returns it.
Sourcepub const fn coordinator(&self) -> &String
pub const fn coordinator(&self) -> &String
Get the coordinator type for this coordinator
Sourcepub const fn sender(&self) -> &Sender<ComponentCmd>
pub const fn sender(&self) -> &Sender<ComponentCmd>
Get a reference to the sender for this coordinator